@@ -95,16 +95,6 @@ class DetectController:
                 return res.json()
             raise Exception(res.text)
 
-    @verify_credentials
-    def social_stats(self, ident: str, days: int = 30):
-        """ Pull social statistics for a specific test """
-        with Spinner():
-            params = dict(days=days)
-            res = requests.get(f'{self.account.hq}/detect/{ident}/social', headers=self.account.headers, params=params)
-            if res.status_code == 200:
-                return res.json()
-            raise Exception(res.text)
-
     @verify_credentials
     def recommendations(self):
         """ List all security recommendations for your account """
